<?php    
/**
 * @package FacebookComments
 * @author Emylee Schonhoeft <emirii.mei@gmail.com>
 * @copyright Copyright (c) 2015 Emylee Schonhoeft. (http://www.ificouldfly.net/)
 * @license http://opensource.org/licenses/GPL-3.0 Open Source GPL v3.0
 *
 */
namespace Concrete\Package\EmiriiDiscussionESFacebookComments\Block\EmiriiDiscussionESFacebookComments;

use \Concrete\Core\Block\BlockController;
use Loader;
use Page;

class Controller extends BlockController {
    
    protected $btTable = 'btEmiriiDiscussionESFacebookComments';
    protected $btInterfaceWidth = "450";
    protected $btInterfaceHeight = "500";
    
    public function getBlockTypeDescription() { return t("Add Facebook comments to any of your pages!"); }
    public function getBlockTypeName() { return t("DiscussionES Facebook Comments"); }

	public function view() {		
		$this->set('bID', $this->bID);
		$this->set('url', $this->getCurrentUrl());
		$this->set('width', $this->width);
		$this->set('num_posts', $this->num_posts);
		$this->set('colorscheme', $this->colorscheme);	
		$this->set('order_by', $this->order_by);	
		$this->set('appID', $this->appID);	
	}
	
	public function add() {
		$this->edit();	
	}
	
	public function edit() {
		$this->width = $this->width ? $this->width : 550;
		$this->num_posts = $this->num_posts ? $this->num_posts : 5;
		$this->set('width', $this->width);
		$this->set('num_posts', $this->num_posts);
		$this->set('colorscheme', $this->colorscheme);	
		$this->set('order_by', $this->order_by);	
		$this->set('appID', $this->appID);
	}
	
	public function save($args) {
		parent::save($args);	
	}
	
    public function validate($args) {
        $val = Loader::helper('validation/error');  
        
        if (!is_numeric($_POST['width']) || intval($_POST['width']) < 1) {
            $val->add(t('Width must be a valid number greater than 1.'));
        }
        
        if (!is_numeric($_POST['num_posts']) || intval($_POST['num_posts']) < 1) {
            $val->add(t('Number of posts must be a valid number greater than 1.'));
        }
		
        if ($_POST['colorscheme'] == '') {
            $val->add(t('You must select a color theme.'));
        }	
		
        if ($_POST['order_by'] == '') {
            $val->add(t('You must select a sort order.'));
        }		
		
        if ($_POST['appID'] == '') {
            $val->add(t('You must input a valid App ID or this block will not work.'));
		} elseif (strlen($_POST['appID']) > 255) {
			$val->add(t('Your App ID should not be longer than 255 characters.'));
		}
			
       return $val;
    }

	private function getCurrentUrl() {
		$currentPage = Page::getCurrentPage();
		$nav = Loader::helper('navigation');
		return $nav->getLinkToCollection($currentPage, true);
	}
}
